tlslite.messages.HandshakeMsg

Package tlslite :: Module messages :: Class HandshakeMsg |
[hide private]
[frames] | no frames]

# Class HandshakeMsg

source code

    object --+
             |
            HandshakeMsg

Known Subclasses:
  - Certificate
  - , CertificateRequest
  - , CertificateVerify
  - , ClientHello
  - , ClientKeyExchange
  - , Finished
  - , NextProtocol
  - , ServerHello
  - , ServerHelloDone
  - , ServerKeyExchange

Instance Methods | [hide private]
__init__(self, handshakeType) x.__init__(...) initializes x; see help(type(x)) for signature | source code
postWrite(self, w) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, handshakeType) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)